@@ -31,6 +31,7 @@
 #include "vteenums.h"
 #include "vtemacros.h"
 #include "vtepty.h"
+#include "vteregex.h"
 
 G_BEGIN_DECLS
 
@@ -42,7 +43,6 @@ G_BEGIN_DECLS
 #define VTE_TERMINAL_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS ((obj),  VTE_TYPE_TERMINAL, VteTerminalClass))
 
 typedef struct _VteTerminal             VteTerminal;
-typedef struct _VteTerminalPrivate      VteTerminalPrivate;
 typedef struct _VteTerminalClass        VteTerminalClass;
 typedef struct _VteTerminalClassPrivate VteTerminalClassPrivate;
 typedef struct _VteCharAttributes       VteCharAttributes;
@@ -53,7 +53,7 @@ typedef struct _VteCharAttributes       VteCharAttributes;
 struct _VteTerminal {
 	GtkWidget widget;
         /*< private >*/
-	VteTerminalPrivate *pvt;
+	gpointer *_unused_padding[1]; /* FIXMEchpe: remove this field on the next ABI break */
 };
 
 /**
@@ -124,130 +124,228 @@ typedef gboolean (*VteSelectionFunc)(VteTerminal *terminal,
                                      gpointer data) _VTE_GNUC_NONNULL(1);
 
 /* The widget's type. */
+_VTE_PUBLIC
 GType vte_terminal_get_type(void);
 
+_VTE_PUBLIC
 GtkWidget *vte_terminal_new(void);
 
+_VTE_PUBLIC
 VtePty *vte_terminal_pty_new_sync (VteTerminal *terminal,
                                    VtePtyFlags flags,
                                    GCancellable *cancellable,
                                    GError **error) _VTE_GNUC_NONNULL(1);
 
+_VTE_PUBLIC
 void vte_terminal_watch_child (VteTerminal *terminal,
                                GPid child_pid) _VTE_GNUC_NONNULL(1);
 
-gboolean vte_terminal_spawn_sync(VteTerminal *terminal,
-                                 VtePtyFlags pty_flags,
-                                 const char *working_directory,
-                                 char **argv,
-                                 char **envv,
-                                 GSpawnFlags spawn_flags,
-                                 GSpawnChildSetupFunc child_setup,
-                                 gpointer child_setup_data,
-                                 GPid *child_pid /* out */,
-                                 GCancellable *cancellable,
-                                 GError **error) _VTE_GNUC_NONNULL(1) _VTE_GNUC_NONNULL(4);
+typedef void (* VteTerminalSpawnAsyncCallback) (VteTerminal *terminal,
+                                                GPid pid,
+                                                GError *error,
+                                                gpointer user_data);
+
+_VTE_PUBLIC
+void vte_terminal_spawn_async(VteTerminal *terminal,
+                              VtePtyFlags pty_flags,
+                              const char *working_directory,
+                              char **argv,
+                              char **envv,
+                              GSpawnFlags spawn_flags_,
+                              GSpawnChildSetupFunc child_setup,
+                              gpointer child_setup_data,
+                              GDestroyNotify child_setup_data_destroy,
+                              int timeout,
+                              GCancellable *cancellable,
+                              VteTerminalSpawnAsyncCallback callback,
+                              gpointer user_data) _VTE_GNUC_NONNULL(1) _VTE_GNUC_NONNULL(4);
 
 /* Send data to the terminal to display, or to the terminal's forked command
  * to handle in some way.  If it's 'cat', they should be the same. */
+_VTE_PUBLIC
 void vte_terminal_feed(VteTerminal *terminal,
                        const char *data,
                        gssize length) _VTE_GNUC_NONNULL(1);
+_VTE_PUBLIC
 void vte_terminal_feed_child(VteTerminal *terminal,
                              const char *text,
                              gssize length) _VTE_GNUC_NONNULL(1);
+_VTE_PUBLIC
 void vte_terminal_feed_child_binary(VteTerminal *terminal,
                                     const guint8 *data,
                                     gsize length) _VTE_GNUC_NONNULL(1);
 
 /* Copy currently-selected text to the clipboard, or from the clipboard to
  * the terminal. */
-void vte_terminal_copy_clipboard(VteTerminal *terminal) _VTE_GNUC_NONNULL(1);
+_VTE_PUBLIC
+void vte_terminal_copy_clipboard_format(VteTerminal *terminal,
+                                        VteFormat format) _VTE_GNUC_NONNULL(1);
+_VTE_PUBLIC
 void vte_terminal_paste_clipboard(VteTerminal *terminal) _VTE_GNUC_NONNULL(1);
+_VTE_PUBLIC
 void vte_terminal_copy_primary(VteTerminal *terminal) _VTE_GNUC_NONNULL(1);
+_VTE_PUBLIC
 void vte_terminal_paste_primary(VteTerminal *terminal) _VTE_GNUC_NONNULL(1);
-
+_VTE_PUBLIC
 void vte_terminal_select_all(VteTerminal *terminal) _VTE_GNUC_NONNULL(1);
+_VTE_PUBLIC
 void vte_terminal_unselect_all(VteTerminal *terminal) _VTE_GNUC_NONNULL(1);
 
+/* By-word selection */
+_VTE_PUBLIC
+void vte_terminal_set_word_char_exceptions(VteTerminal *terminal,
+                                           const char *exceptions) _VTE_GNUC_NONNULL(1);
+_VTE_PUBLIC
+const char *vte_terminal_get_word_char_exceptions(VteTerminal *terminal) _VTE_GNUC_NONNULL(1);
+
 /* Set the terminal's size. */
+_VTE_PUBLIC
 void vte_terminal_set_size(VteTerminal *terminal,
 			   glong columns, glong rows) _VTE_GNUC_NONNULL(1);
 
+_VTE_PUBLIC
 void vte_terminal_set_font_scale(VteTerminal *terminal,
                                  gdouble scale) _VTE_GNUC_NONNULL(1);
+_VTE_PUBLIC
 gdouble vte_terminal_get_font_scale(VteTerminal *terminal) _VTE_GNUC_NONNULL(1);
 
+_VTE_PUBLIC
+void vte_terminal_set_cell_width_scale(VteTerminal *terminal,
+                                       double scale) _VTE_GNUC_NONNULL(1);
+_VTE_PUBLIC
+double vte_terminal_get_cell_width_scale(VteTerminal *terminal) _VTE_GNUC_NONNULL(1);
+
+_VTE_PUBLIC
+void vte_terminal_set_cell_height_scale(VteTerminal *terminal,
+                                        double scale) _VTE_GNUC_NONNULL(1);
+_VTE_PUBLIC
+double vte_terminal_get_cell_height_scale(VteTerminal *terminal) _VTE_GNUC_NONNULL(1);
+
 /* Set various on-off settings. */
+_VTE_PUBLIC
+void vte_terminal_set_text_blink_mode(VteTerminal *terminal,
+                                      VteTextBlinkMode text_blink_mode) _VTE_GNUC_NONNULL(1);
+_VTE_PUBLIC
+VteTextBlinkMode vte_terminal_get_text_blink_mode(VteTerminal *terminal) _VTE_GNUC_NONNULL(1);
+_VTE_PUBLIC
 void vte_terminal_set_audible_bell(VteTerminal *terminal,
                                    gboolean is_audible) _VTE_GNUC_NONNULL(1);
+_VTE_PUBLIC
 gboolean vte_terminal_get_audible_bell(VteTerminal *terminal);
+_VTE_PUBLIC
 void vte_terminal_set_scroll_on_output(VteTerminal *terminal,
                                        gboolean scroll) _VTE_GNUC_NONNULL(1);
+_VTE_PUBLIC
+gboolean vte_terminal_get_scroll_on_output(VteTerminal *terminal) _VTE_GNUC_NONNULL(1);
+_VTE_PUBLIC
 void vte_terminal_set_scroll_on_keystroke(VteTerminal *terminal,
 					  gboolean scroll);
+_VTE_PUBLIC
+gboolean vte_terminal_get_scroll_on_keystroke(VteTerminal *terminal) _VTE_GNUC_NONNULL(1);
+_VTE_PUBLIC
 void vte_terminal_set_rewrap_on_resize(VteTerminal *terminal,
                                        gboolean rewrap) _VTE_GNUC_NONNULL(1);
+_VTE_PUBLIC
 gboolean vte_terminal_get_rewrap_on_resize(VteTerminal *terminal) _VTE_GNUC_NONNULL(1);
 
 /* Set the color scheme. */
+_VTE_PUBLIC
 void vte_terminal_set_color_bold(VteTerminal *terminal,
                                  const GdkRGBA *bold) _VTE_GNUC_NONNULL(1);
+_VTE_PUBLIC
 void vte_terminal_set_color_foreground(VteTerminal *terminal,
                                        const GdkRGBA *foreground) _VTE_GNUC_NONNULL(1) _VTE_GNUC_NONNULL(2);
+_VTE_PUBLIC
 void vte_terminal_set_color_background(VteTerminal *terminal,
                                        const GdkRGBA *background) _VTE_GNUC_NONNULL(1) _VTE_GNUC_NONNULL(2);
+_VTE_PUBLIC
 void vte_terminal_set_color_cursor(VteTerminal *terminal,
                                    const GdkRGBA *cursor_background) _VTE_GNUC_NONNULL(1);
+_VTE_PUBLIC
+void vte_terminal_set_color_cursor_foreground(VteTerminal *terminal,
+                                              const GdkRGBA *cursor_foreground) _VTE_GNUC_NONNULL(1);
+_VTE_PUBLIC
 void vte_terminal_set_color_highlight(VteTerminal *terminal,
                                       const GdkRGBA *highlight_background) _VTE_GNUC_NONNULL(1);
+_VTE_PUBLIC
 void vte_terminal_set_color_highlight_foreground(VteTerminal *terminal,
                                                  const GdkRGBA *highlight_foreground) _VTE_GNUC_NONNULL(1);
+_VTE_PUBLIC
 void vte_terminal_set_colors(VteTerminal *terminal,
                              const GdkRGBA *foreground,
                              const GdkRGBA *background,
                              const GdkRGBA *palette,
                              gsize palette_size) _VTE_GNUC_NONNULL(1);
 
+_VTE_PUBLIC
 void vte_terminal_set_default_colors(VteTerminal *terminal) _VTE_GNUC_NONNULL(1);
 
 /* Set whether or not the cursor blinks. */
+_VTE_PUBLIC
 void vte_terminal_set_cursor_blink_mode(VteTerminal *terminal,
 					VteCursorBlinkMode mode) _VTE_GNUC_NONNULL(1);
+_VTE_PUBLIC
 VteCursorBlinkMode vte_terminal_get_cursor_blink_mode(VteTerminal *terminal) _VTE_GNUC_NONNULL(1);
 
 /* Set cursor shape */
+_VTE_PUBLIC
 void vte_terminal_set_cursor_shape(VteTerminal *terminal,
 				   VteCursorShape shape) _VTE_GNUC_NONNULL(1);
+_VTE_PUBLIC
 VteCursorShape vte_terminal_get_cursor_shape(VteTerminal *terminal) _VTE_GNUC_NONNULL(1);
 
 /* Set the number of scrollback lines, above or at an internal minimum. */
+_VTE_PUBLIC
 void vte_terminal_set_scrollback_lines(VteTerminal *terminal,
                                        glong lines) _VTE_GNUC_NONNULL(1);
+_VTE_PUBLIC
+glong vte_terminal_get_scrollback_lines(VteTerminal *terminal) _VTE_GNUC_NONNULL(1);
 
 /* Set or retrieve the current font. */
+_VTE_PUBLIC
 void vte_terminal_set_font(VteTerminal *terminal,
 			   const PangoFontDescription *font_desc) _VTE_GNUC_NONNULL(1);
+_VTE_PUBLIC
 const PangoFontDescription *vte_terminal_get_font(VteTerminal *terminal) _VTE_GNUC_NONNULL(1);
+_VTE_PUBLIC
 void vte_terminal_set_allow_bold(VteTerminal *terminal,
                                  gboolean allow_bold) _VTE_GNUC_NONNULL(1);
+_VTE_PUBLIC
 gboolean vte_terminal_get_allow_bold(VteTerminal *terminal) _VTE_GNUC_NONNULL(1);
 
+_VTE_PUBLIC
+void vte_terminal_set_bold_is_bright(VteTerminal *terminal,
+                                     gboolean bold_is_bright) _VTE_GNUC_NONNULL(1);
+_VTE_PUBLIC
+gboolean vte_terminal_get_bold_is_bright(VteTerminal *terminal) _VTE_GNUC_NONNULL(1);
+
+_VTE_PUBLIC
+void vte_terminal_set_allow_hyperlink(VteTerminal *terminal,
+                                      gboolean allow_hyperlink) _VTE_GNUC_NONNULL(1);
+_VTE_PUBLIC
+gboolean vte_terminal_get_allow_hyperlink(VteTerminal *terminal) _VTE_GNUC_NONNULL(1);
+
 /* Check if the terminal is the current selection owner. */
+_VTE_PUBLIC
 gboolean vte_terminal_get_has_selection(VteTerminal *terminal) _VTE_GNUC_NONNULL(1);
 
 /* Set what happens when the user strikes backspace or delete. */
+_VTE_PUBLIC
 void vte_terminal_set_backspace_binding(VteTerminal *terminal,
 					VteEraseBinding binding) _VTE_GNUC_NONNULL(1);
+_VTE_PUBLIC
 void vte_terminal_set_delete_binding(VteTerminal *terminal,
 				     VteEraseBinding binding) _VTE_GNUC_NONNULL(1);
 
 /* Manipulate the autohide setting. */
+_VTE_PUBLIC
 void vte_terminal_set_mouse_autohide(VteTerminal *terminal,
                                      gboolean setting) _VTE_GNUC_NONNULL(1);
+_VTE_PUBLIC
 gboolean vte_terminal_get_mouse_autohide(VteTerminal *terminal) _VTE_GNUC_NONNULL(1);
 
 /* Reset the terminal, optionally clearing the tab stops and line history. */
+_VTE_PUBLIC
 void vte_terminal_reset(VteTerminal *terminal,
                         gboolean clear_tabstops,
 			gboolean clear_history) _VTE_GNUC_NONNULL(1);
@@ -258,109 +356,137 @@ void vte_terminal_reset(VteTerminal *terminal,
  * VteCharAttributes structure in the passed GArray, if the array was not %NULL.
  * Note that it will have one entry per byte, not per character, so indexes
  * should match up exactly. */
+_VTE_PUBLIC
 char *vte_terminal_get_text(VteTerminal *terminal,
 			    VteSelectionFunc is_selected,
 			    gpointer user_data,
 			    GArray *attributes) _VTE_GNUC_NONNULL(1) G_GNUC_MALLOC;
+_VTE_PUBLIC
 char *vte_terminal_get_text_include_trailing_spaces(VteTerminal *terminal,
 						    VteSelectionFunc is_selected,
 						    gpointer user_data,
 						    GArray *attributes) _VTE_GNUC_NONNULL(1) G_GNUC_MALLOC;
+_VTE_PUBLIC
 char *vte_terminal_get_text_range(VteTerminal *terminal,
 				  glong start_row, glong start_col,
 				  glong end_row, glong end_col,
 				  VteSelectionFunc is_selected,
 				  gpointer user_data,
 				  GArray *attributes) _VTE_GNUC_NONNULL(1) G_GNUC_MALLOC;
+_VTE_PUBLIC
 void vte_terminal_get_cursor_position(VteTerminal *terminal,
 				      glong *column,
                                       glong *row) _VTE_GNUC_NONNULL(1);
 
+_VTE_PUBLIC
+char *vte_terminal_hyperlink_check_event(VteTerminal *terminal,
+                                         GdkEvent *event) _VTE_GNUC_NONNULL(1) _VTE_GNUC_NONNULL(2) G_GNUC_MALLOC;
+
 /* Add a matching expression, returning the tag the widget assigns to that
  * expression. */
-int vte_terminal_match_add_gregex(VteTerminal *terminal,
-                                  GRegex *regex,
-                                  GRegexMatchFlags flags) _VTE_GNUC_NONNULL(1);
+_VTE_PUBLIC
+int vte_terminal_match_add_regex(VteTerminal *terminal,
+                                 VteRegex *regex,
+                                 guint32 flags) _VTE_GNUC_NONNULL(1) _VTE_GNUC_NONNULL(2);
 /* Set the cursor to be used when the pointer is over a given match. */
-void vte_terminal_match_set_cursor(VteTerminal *terminal,
-                                   int tag,
-				   GdkCursor *cursor) _VTE_GNUC_NONNULL(1);
-void vte_terminal_match_set_cursor_type(VteTerminal *terminal,
-					int tag,
-                                        GdkCursorType cursor_type) _VTE_GNUC_NONNULL(1);
+_VTE_PUBLIC
 void vte_terminal_match_set_cursor_name(VteTerminal *terminal,
 					int tag,
                                         const char *cursor_name) _VTE_GNUC_NONNULL(1) _VTE_GNUC_NONNULL(3);
+_VTE_PUBLIC
 void vte_terminal_match_remove(VteTerminal *terminal,
                                int tag) _VTE_GNUC_NONNULL(1);
+_VTE_PUBLIC
 void vte_terminal_match_remove_all(VteTerminal *terminal) _VTE_GNUC_NONNULL(1);
 
 /* Check if a given cell on the screen contains part of a matched string.  If
  * it does, return the string, and store the match tag in the optional tag
  * argument. */
-char *vte_terminal_match_check(VteTerminal *terminal,
-			       glong column, glong row,
-			       int *tag) _VTE_GNUC_NONNULL(1) G_GNUC_MALLOC;
+_VTE_PUBLIC
 char *vte_terminal_match_check_event(VteTerminal *terminal,
                                      GdkEvent *event,
                                      int *tag) _VTE_GNUC_NONNULL(1) _VTE_GNUC_NONNULL(2) G_GNUC_MALLOC;
+_VTE_PUBLIC
+gboolean vte_terminal_event_check_regex_simple(VteTerminal *terminal,
+                                               GdkEvent *event,
+                                               VteRegex **regexes,
+                                               gsize n_regexes,
+                                               guint32 match_flags,
+                                               char **matches) _VTE_GNUC_NONNULL(1) _VTE_GNUC_NONNULL(2);
 
-void      vte_terminal_search_set_gregex      (VteTerminal *terminal,
-					       GRegex      *regex,
-                                               GRegexMatchFlags flags) _VTE_GNUC_NONNULL(1);
-GRegex   *vte_terminal_search_get_gregex      (VteTerminal *terminal) _VTE_GNUC_NONNULL(1);
+_VTE_PUBLIC
+void      vte_terminal_search_set_regex      (VteTerminal *terminal,
+                                              VteRegex    *regex,
+                                              guint32      flags) _VTE_GNUC_NONNULL(1);
+_VTE_PUBLIC
+VteRegex *vte_terminal_search_get_regex      (VteTerminal *terminal) _VTE_GNUC_NONNULL(1);
+_VTE_PUBLIC
 void      vte_terminal_search_set_wrap_around (VteTerminal *terminal,
 					       gboolean     wrap_around) _VTE_GNUC_NONNULL(1);
+_VTE_PUBLIC
 gboolean  vte_terminal_search_get_wrap_around (VteTerminal *terminal) _VTE_GNUC_NONNULL(1);
+_VTE_PUBLIC
 gboolean  vte_terminal_search_find_previous   (VteTerminal *terminal) _VTE_GNUC_NONNULL(1);
+_VTE_PUBLIC
 gboolean  vte_terminal_search_find_next       (VteTerminal *terminal) _VTE_GNUC_NONNULL(1);
 
 
-/* Set the character encoding.  Most of the time you won't need this. */
-gboolean vte_terminal_set_encoding(VteTerminal *terminal,
-                                   const char *codeset,
-                                   GError **error) _VTE_GNUC_NONNULL(1);
-const char *vte_terminal_get_encoding(VteTerminal *terminal) _VTE_GNUC_NONNULL(1);
-
 /* CJK compatibility setting */
+_VTE_PUBLIC
 void vte_terminal_set_cjk_ambiguous_width(VteTerminal *terminal,
                                           int width) _VTE_GNUC_NONNULL(1);
+_VTE_PUBLIC
 int vte_terminal_get_cjk_ambiguous_width(VteTerminal *terminal) _VTE_GNUC_NONNULL(1);
 
+_VTE_PUBLIC
 void vte_terminal_set_pty(VteTerminal *terminal,
                           VtePty *pty) _VTE_GNUC_NONNULL(1);
+_VTE_PUBLIC
 VtePty *vte_terminal_get_pty(VteTerminal *terminal) _VTE_GNUC_NONNULL(1);
 
 /* Accessors for bindings. */
+_VTE_PUBLIC
 glong vte_terminal_get_char_width(VteTerminal *terminal) _VTE_GNUC_NONNULL(1);
+_VTE_PUBLIC
 glong vte_terminal_get_char_height(VteTerminal *terminal) _VTE_GNUC_NONNULL(1);
+_VTE_PUBLIC
 glong vte_terminal_get_row_count(VteTerminal *terminal) _VTE_GNUC_NONNULL(1);
+_VTE_PUBLIC
 glong vte_terminal_get_column_count(VteTerminal *terminal) _VTE_GNUC_NONNULL(1);
+_VTE_PUBLIC
 const char *vte_terminal_get_window_title(VteTerminal *terminal) _VTE_GNUC_NONNULL(1);
-const char *vte_terminal_get_icon_title(VteTerminal *terminal) _VTE_GNUC_NONNULL(1);
+_VTE_PUBLIC
 const char *vte_terminal_get_current_directory_uri(VteTerminal *terminal) _VTE_GNUC_NONNULL(1);
+_VTE_PUBLIC
 const char *vte_terminal_get_current_file_uri(VteTerminal *terminal) _VTE_GNUC_NONNULL(1);
 
 /* misc */
+_VTE_PUBLIC
 void vte_terminal_set_input_enabled (VteTerminal *terminal,
                                      gboolean enabled) _VTE_GNUC_NONNULL(1);
+_VTE_PUBLIC
 gboolean vte_terminal_get_input_enabled (VteTerminal *terminal) _VTE_GNUC_NONNULL(1);
 
-/* Window geometry helpers */
-void vte_terminal_get_geometry_hints(VteTerminal *terminal,
-                                     GdkGeometry *hints,
-                                     int min_rows,
-                                     int min_columns) _VTE_GNUC_NONNULL(1) _VTE_GNUC_NONNULL(2);
-void vte_terminal_set_geometry_hints_for_window(VteTerminal *terminal,
-                                                GtkWindow *window) _VTE_GNUC_NONNULL(1) _VTE_GNUC_NONNULL(2);
+/* rarely useful functions */
+_VTE_PUBLIC
+void vte_terminal_set_clear_background(VteTerminal* terminal,
+                                       gboolean setting) _VTE_GNUC_NONNULL(1);
+_VTE_PUBLIC
+void vte_terminal_get_color_background_for_draw(VteTerminal* terminal,
+                                                GdkRGBA* color) _VTE_GNUC_NONNULL(1) _VTE_GNUC_NONNULL(2);
 
 /* Writing contents out */
+_VTE_PUBLIC
 gboolean vte_terminal_write_contents_sync (VteTerminal *terminal,
                                            GOutputStream *stream,
                                            VteWriteFlags flags,
                                            GCancellable *cancellable,
                                            GError **error) _VTE_GNUC_NONNULL(1) _VTE_GNUC_NONNULL(2);
 
+#if GLIB_CHECK_VERSION(2, 44, 0)
+G_DEFINE_AUTOPTR_CLEANUP_FUNC(VteTerminal, g_object_unref)
+#endif
+
 G_END_DECLS
 
 #endif /* __VTE_VTE_TERMINAL_H__ */
